@@ -1,6 +1,6 @@
 // 2004-03-02  Petur Runolfsson  <peturr02@ru.is>
 
-// Copyright (C) 2004-2024 Free Software Foundation, Inc.
+// Copyright (C) 2004-2025 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -22,21 +22,31 @@
 // 27.4.3 fpos
 
 #include <iterator>
-#include <limits>
 #include <testsuite_hooks.h>
 
+class Fred
+{
+public:
+  Fred(bool)
+  { }
+};
+
+void barney(Fred)
+{ }
+
+// libstdc++/14320
 void test01()
 {
   using namespace std;
 
   typedef istreambuf_iterator<char>::difference_type Distance;
-  typedef numeric_limits<Distance> Limits;
-
-  VERIFY( Limits::is_specialized );
-  VERIFY( Limits::is_signed );
+  
+  Distance d = 0;
+  barney(d);
 }
 
 int main()
 {
   test01();
+  return 0;
 }
