@@ -19,18 +19,20 @@
 
 #include <iostream>
 
-// libstdc++/6648
-// Interactive tests: each one (run alone) must terminate upon a single '\n'.
-void test08()
+// libstdc++/2523
+void test03()
 {
-  wchar_t buff[2048];
-  std::wcout << "Enter name: ";
-  std::wcin.getline(buff, 2048);
+  using namespace std;
+  ios_base::sync_with_stdio(false);
+
+  int i;
+  wcin >> i;
+  wcout << "i == " << i << endl;
 }
 
 int 
 main()
 {
-  test08();
+  test03();
   return 0;
 }
